@@ -112,7 +112,13 @@ class Processor {
       let prop = decl.prop
       let value = decl.value
 
-      if (prop === 'grid-row-span') {
+      if (prop === 'color-adjust') {
+        result.warn(
+          'Replace color-adjust to print-color-adjust. ' +
+            'The color-adjust shorthand is currently deprecated.',
+          { node: decl }
+        )
+      } else if (prop === 'grid-row-span') {
         result.warn(
           'grid-row-span is not part of final Grid Layout. Use grid-row.',
           { node: decl }
